OrthogonalityRegularizer
========================

.. currentmodule:: pykeen.regularizers

.. autoclass:: OrthogonalityRegularizer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~OrthogonalityRegularizer.forward
      ~OrthogonalityRegularizer.update

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: update
